#!/usr/bin/env python3
import argparse
import sys
from typing import Optional, Tuple

from pimg import __version__

from . import pimg


def parse_args(test: Optional[Tuple[str]] = None) -> argparse.Namespace:
    parser = argparse.ArgumentParser(
        prog="pimg",
        formatter_class=argparse.RawDescriptionHelpFormatter,
        description="Save an image in clipboard",
    )

    parser.add_argument(
        "savefile", metavar="savefile", type=str, help="File name to save"
    )
    parser.add_argument(
        "-V", "--version", action="version", version="%(prog)s {}".format(__version__)
    )

    if test is None:
        args = parser.parse_args()
    else:
        args = parser.parse_args(test)
    return args


def main() -> None:
    args = parse_args()
    try:
        p = pimg.Pimg(args.savefile)
    except pimg.PimgSavePathError as e:
        print(str(e), file=sys.stderr)
        exit(1)

    try:
        p.get_clip_img()
    except (pimg.PimgClipBoardError, pimg.PimgGLibError) as e:
        print(str(e), file=sys.stderr)
        exit(1)


if __name__ == "__main__":
    try:
        main()
    except KeyboardInterrupt:
        pass



import os
from typing import Any

import gi

if gi.get_required_version("Gdk") is None:  # type: ignore[attr-defined]
    gi.require_version("Gdk", "3.0")

if gi.get_required_version("Gtk") is None:  # type: ignore[attr-defined]
    gi.require_version("Gtk", "3.0")

from gi.repository import Gdk, Gtk


class PimgSavePathError(Exception):
    pass


class PimgClipBoardError(Exception):
    pass


class PimgGLibError(Exception):
    pass


class Pimg:

    EXTS = ["png", "bmp", "jpg", "jpeg", "tiff"]

    def __init__(self, savefile: Any) -> None:
        self.save_fname = savefile
        self.ext = self._check_file_format()

    def _check_file_format(self) -> str:
        ext = os.path.splitext(self.save_fname)[1]
        ext = str(ext).replace(".", "")
        if ext == "":
            raise PimgSavePathError(
                "Save filename '" + self.save_fname + "' does not contain an extension."
            )
        elif ext not in self.EXTS:
            raise PimgSavePathError(
                "Save file extension '" + ext + "' seem to be invalid. "
            )
        else:
            return str(ext)

    def get_clip_img(self) -> None:
        try:
            self._get_clip_img()
        except Exception as e:
            raise PimgGLibError(str(e))

    def _get_clip_img(self) -> None:
        cb = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
        pixbuf = cb.wait_for_image()
        if pixbuf is None:
            raise PimgClipBoardError("Image does not exist in your clipboard.")
        else:
            pixbuf.savev(self.save_fname, self.ext, [], [])
